SQUserRefField class

Inheritance
Implementers

Constructors

SQUserRefField(String name)

Properties

collection ↔ SQCollection
getter/setter pairinherited
defaultValue ↔ SQRef?
getter/setter pairinherited
editable ↔ bool
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNavigateAction ↔ bool
getter/setter pairinherited
isInline ↔ bool
getter/setter pairinherited
isLive ↔ bool
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
require ↔ bool
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
show ↔ DocCond
getter/setter pairinherited

Methods

formField(DocScreen docScreen) → SQFormField<SQRef, SQField<SQRef>>
inherited
init(SQDoc doc) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(dynamic source) → SQRef?
inherited
serialize(SQRef? value) → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
valueDisplay(SQRef? value) → Widget
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited