SQInverseRefsField class
Constructors
- SQInverseRefsField(String name, {required SQCollection refCollection(), required String refFieldName})
Properties
- collection → SQCollection
-
no setter
-
defaultValue
↔ List<
SQRef?> ? -
getter/setter pairinherited
- editable ↔ bool
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInline ↔ bool
-
getter/setter pairinherited
- isLive ↔ bool
-
getter/setter pairinherited
- name ↔ String
-
getter/setter pairinherited
- refCollection ↔ SQCollection Function()
-
getter/setter pair
- refFieldName ↔ String
-
getter/setter pair
- require ↔ bool
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show ↔ DocCond
-
getter/setter pairinherited
-
subfield
↔ SQField<
List< SQRef?> > -
getter/setter pairinherited
-
valueBuilder
↔ List<
SQRef?> Function(SQDoc doc) -
getter/setter pairinherited
Methods
-
formField(
DocScreen docScreen) → SQFormField< List< SQRef?> , SQField<List< >SQRef?> > -
override
-
init(
SQDoc doc) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
dynamic source) → List< SQRef?> ? -
inherited
-
serialize(
List< SQRef?> ? value) → dynamic -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
valueDisplay(
List< SQRef?> ? value) → Widget -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited